#!/bin/sh

# script to help determine what is using backup space
# written by Adrian Bridgett

topdir="/var/lib/backuppc"
type="incr"

set -e

usage()
{
  cat <<EOF
Usage: `basename $0` -a|-h hostname [-i|-f]

reports backup stats for all hosts or a single host.
will report last five incrementals [-i or default]
or last five full backups [-f]

EOF
  exit 1
}

main()
{
  hosts=""
  while getopts "ah:if" opt; do
    case "$opt" in
      h) hosts="$hosts $OPTARG";;
      a) hosts=`/bin/ls "$topdir/pc"`;;
      i) type="incr";;
      f) type="full";;
    esac
  done
  shift $(($OPTIND - 1))

  [ "$hosts" ] || usage

  for host in $hosts; do
    print_stats $host
    echo
  done
}

print_stats()
{
  local host="$1"
  grep "$type" "$topdir/pc/$host/backups" | tail -n5 | \
  awk -v host=$host 'BEGIN {print "Mins  Files  Size  Comp"}
       {printf "%4d  %5d %5d %5d %s\n", ($4-$3)/60, $9, $10/1024/1024, $17/1024/1024, host}'
}

main "$@"

